@@ -63,6 +63,7 @@ RetentionActionType = Literal["DELETE", "NONE", "PERMANENTLY_DELETE"]
 UserRoleType = Literal["RESOURCE", "SYSTEM_USER", "USER"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -95,6 +96,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
