@@ -56,6 +56,7 @@ __all__ = (
     "DeleteAliasRequestRequestTypeDef",
     "DeleteGroupRequestRequestTypeDef",
     "DeleteMailboxPermissionsRequestRequestTypeDef",
+    "DeleteMobileDeviceAccessOverrideRequestRequestTypeDef",
     "DeleteMobileDeviceAccessRuleRequestRequestTypeDef",
     "DeleteOrganizationRequestRequestTypeDef",
     "DeleteOrganizationResponseTypeDef",
@@ -85,6 +86,8 @@ __all__ = (
     "GetMailboxDetailsResponseTypeDef",
     "GetMobileDeviceAccessEffectRequestRequestTypeDef",
     "GetMobileDeviceAccessEffectResponseTypeDef",
+    "GetMobileDeviceAccessOverrideRequestRequestTypeDef",
+    "GetMobileDeviceAccessOverrideResponseTypeDef",
     "GroupTypeDef",
     "ListAccessControlRulesRequestRequestTypeDef",
     "ListAccessControlRulesResponseTypeDef",
@@ -98,6 +101,8 @@ __all__ = (
     "ListMailboxExportJobsResponseTypeDef",
     "ListMailboxPermissionsRequestRequestTypeDef",
     "ListMailboxPermissionsResponseTypeDef",
+    "ListMobileDeviceAccessOverridesRequestRequestTypeDef",
+    "ListMobileDeviceAccessOverridesResponseTypeDef",
     "ListMobileDeviceAccessRulesRequestRequestTypeDef",
     "ListMobileDeviceAccessRulesResponseTypeDef",
     "ListOrganizationsRequestRequestTypeDef",
@@ -113,12 +118,14 @@ __all__ = (
     "MailboxExportJobTypeDef",
     "MemberTypeDef",
     "MobileDeviceAccessMatchedRuleTypeDef",
+    "MobileDeviceAccessOverrideTypeDef",
     "MobileDeviceAccessRuleTypeDef",
     "OrganizationSummaryTypeDef",
     "PaginatorConfigTypeDef",
     "PermissionTypeDef",
     "PutAccessControlRuleRequestRequestTypeDef",
     "PutMailboxPermissionsRequestRequestTypeDef",
+    "PutMobileDeviceAccessOverrideRequestRequestTypeDef",
     "PutRetentionPolicyRequestRequestTypeDef",
     "RegisterToWorkMailRequestRequestTypeDef",
     "ResetPasswordRequestRequestTypeDef",
@@ -368,6 +375,15 @@ DeleteMailboxPermissionsRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
+    "DeleteMobileDeviceAccessOverrideRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "UserId": str,
+        "DeviceId": str,
+    },
+)
+
 DeleteMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
     "DeleteMobileDeviceAccessRuleRequestRequestTypeDef",
     {
@@ -694,6 +710,28 @@ GetMobileDeviceAccessEffectResponseTypeDef = TypedDict(
     },
 )
 
+GetMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
+    "GetMobileDeviceAccessOverrideRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "UserId": str,
+        "DeviceId": str,
+    },
+)
+
+GetMobileDeviceAccessOverrideResponseTypeDef = TypedDict(
+    "GetMobileDeviceAccessOverrideResponseTypeDef",
+    {
+        "UserId": str,
+        "DeviceId": str,
+        "Effect": MobileDeviceAccessRuleEffectType,
+        "Description": str,
+        "DateCreated": datetime,
+        "DateModified": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GroupTypeDef = TypedDict(
     "GroupTypeDef",
     {
@@ -882,6 +920,40 @@ ListMailboxPermissionsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListMobileDeviceAccessOverridesRequestRequestTypeDef = TypedDict(
+    "_RequiredListMobileDeviceAccessOverridesRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+_OptionalListMobileDeviceAccessOverridesRequestRequestTypeDef = TypedDict(
+    "_OptionalListMobileDeviceAccessOverridesRequestRequestTypeDef",
+    {
+        "UserId": str,
+        "DeviceId": str,
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListMobileDeviceAccessOverridesRequestRequestTypeDef(
+    _RequiredListMobileDeviceAccessOverridesRequestRequestTypeDef,
+    _OptionalListMobileDeviceAccessOverridesRequestRequestTypeDef,
+):
+    pass
+
+
+ListMobileDeviceAccessOverridesResponseTypeDef = TypedDict(
+    "ListMobileDeviceAccessOverridesResponseTypeDef",
+    {
+        "Overrides": List["MobileDeviceAccessOverrideTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListMobileDeviceAccessRulesRequestRequestTypeDef = TypedDict(
     "ListMobileDeviceAccessRulesRequestRequestTypeDef",
     {
@@ -1063,6 +1135,19 @@ MobileDeviceAccessMatchedRuleTypeDef = TypedDict(
     total=False,
 )
 
+MobileDeviceAccessOverrideTypeDef = TypedDict(
+    "MobileDeviceAccessOverrideTypeDef",
+    {
+        "UserId": str,
+        "DeviceId": str,
+        "Effect": MobileDeviceAccessRuleEffectType,
+        "Description": str,
+        "DateCreated": datetime,
+        "DateModified": datetime,
+    },
+    total=False,
+)
+
 MobileDeviceAccessRuleTypeDef = TypedDict(
     "MobileDeviceAccessRuleTypeDef",
     {
@@ -1155,6 +1240,31 @@ PutMailboxPermissionsRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredPutMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
+    "_RequiredPutMobileDeviceAccessOverrideRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "UserId": str,
+        "DeviceId": str,
+        "Effect": MobileDeviceAccessRuleEffectType,
+    },
+)
+_OptionalPutMobileDeviceAccessOverrideRequestRequestTypeDef = TypedDict(
+    "_OptionalPutMobileDeviceAccessOverrideRequestRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class PutMobileDeviceAccessOverrideRequestRequestTypeDef(
+    _RequiredPutMobileDeviceAccessOverrideRequestRequestTypeDef,
+    _OptionalPutMobileDeviceAccessOverrideRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredPutRetentionPolicyRequestRequestTypeDef = TypedDict(
     "_RequiredPutRetentionPolicyRequestRequestTypeDef",
     {
